@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2019 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
+#    Copyright (C) 2008-2021 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ gettext.textdomain('backintime')
 
 class Config(configfile.ConfigFileWithProfiles):
     APP_NAME = 'Back In Time'
-    VERSION = '1.2.1'
-    COPYRIGHT = 'Copyright (C) 2008-2019 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze'
+    VERSION = '1.3.1'
+    COPYRIGHT = 'Copyright (C) 2008-2021 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze'
     CONFIG_VERSION = 6
 
     NONE = 0
@@ -89,7 +89,8 @@ class Config(configfile.ConfigFileWithProfiles):
                 REPEATEDLY : _('Repeatedly (anacron)'),
                 UDEV : _('When drive get connected (udev)'),
                 WEEK : _('Every Week'),
-                MONTH : _('Every Month')
+                MONTH : _('Every Month'),
+                YEAR : _('Every Year')
                 }
 
     REMOVE_OLD_BACKUP_UNITS = {
@@ -1576,6 +1577,8 @@ class Config(configfile.ConfigFileWithProfiles):
             cron_line = '%s %s * * %s {cmd}' %(minute, hour, weekday)
         elif self.MONTH == backup_mode:
             cron_line = '%s %s %s * * {cmd}' %(minute, hour, day)
+        elif self.YEAR == backup_mode:
+            cron_line = '%s %s 1 1 * {cmd}' %(minute, hour)
 
         return cron_line
 
