@@ -1,4 +1,4 @@
-#    Copyright (C) 2012-2019 Germar Reitze, Taylor Raack
+#    Copyright (C) 2012-2021 Germar Reitze, Taylor Raack
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -607,8 +607,11 @@ class MountControl(object):
         if os.path.ismount(self.currentMountpoint):
             return True
         else:
-            if os.listdir(self.currentMountpoint):
-                raise MountException(_('mountpoint %s not empty.') % self.currentMountpoint)
+            try:
+                if os.listdir(self.currentMountpoint):
+                    raise MountException(_('mountpoint %s not empty.') % self.currentMountpoint)
+            except FileNotFoundError:
+                pass
             return False
 
     def createMountStructure(self):
@@ -648,7 +651,7 @@ class MountControl(object):
         """
         tools.mkdir(self.mount_root, 0o700)
         tools.mkdir(self.hash_id_path, 0o700)
-        tools.mkdir(self.currentMountpoint, 0o700)
+        tools.mkdir(self.currentMountpoint, 0o700, False)
         tools.mkdir(self.lock_path, 0o700)
 
     def mountProcessLockAcquire(self, timeout = 60):
