@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2019 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze, Taylor Raack
+#    Copyright (C) 2008-2021 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze, Taylor Raack
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -287,7 +287,7 @@ def makeDirs(path):
                          %(path, str(e)), traceDepth = 1)
     return os.path.isdir(path)
 
-def mkdir(path, mode = 0o755):
+def mkdir(path, mode = 0o755, enforce_permissions = True):
     """
     Create directory ``path``.
 
@@ -300,7 +300,8 @@ def mkdir(path, mode = 0o755):
     """
     if os.path.isdir(path):
         try:
-            os.chmod(path, mode)
+            if enforce_permissions:
+                os.chmod(path, mode)
         except:
             return False
         return True
@@ -528,9 +529,12 @@ def rsyncCaps(data = None):
         data = proc.communicate()[0]
     caps = []
     #rsync >= 3.1 does provide --info=progress2
-    m = re.match(r'rsync\s*version\s*(\d\.\d)', data)
-    if m and StrictVersion(m.group(1)) >= StrictVersion('3.1'):
-        caps.append('progress2')
+    matchers = [r'rsync\s*version\s*(\d\.\d)', r'rsync\s*version\s*v(\d\.\d.\d)']
+    for matcher in matchers:
+        m = re.match(matcher, data)
+        if m and StrictVersion(m.group(1)) >= StrictVersion('3.1'):
+            caps.append('progress2')
+            break
 
     #all other capabilities are separated by ',' between
     #'Capabilities:' and '\n\n'
